@@ -1,7 +1,7 @@
 """
-==============================================
+===============================================
 Registry of Updaters, Dividers, and Serializers
-==============================================
+===============================================
 
 You should interpret words and phrases that appear fully capitalized in
 this document as described in :rfc:`2119`. Here is a brief summary of
@@ -57,22 +57,6 @@ the variables in each of the daughter cells.
 .. note:: Dividers MAY not be deterministic and MAY not be symmetric.
     For example, a divider splitting an odd, integer-valued value may
     randomly decide which daughter cell receives the remainder.
-
---------
-Derivers
---------
-
-Each :term:`deriver` is defined as a separate :term:`process`, but here
-deriver names are mapped to processes by :py:data:`deriver_registry`. The
-available derivers are:
-
-* **mmol_to_counts**: :py:class:`vivarium.processes.derive_counts.DeriveCounts`
-* **counts_to_mmol**:
-  :py:class:`vivarium.processes.derive_concentrations.DeriveConcentrations`
-* **mass**: :py:class:`vivarium.processes.tree_mass.TreeMass`
-
-See the documentation for each :term:`process class` for more details on
-that deriver.
 """
 
 
@@ -139,12 +123,25 @@ def update_accumulate(current_value, new_value, states):
     """
     return current_value + new_value
 
+def update_nonnegative_accumulate(current_value, new_value, states):
+    """Non-negative Accumulate Updater
+
+    Returns:
+        The sum of ``current_value`` and ``new_value`` if positive, 0 if negative.
+    """
+    updated_value = current_value + new_value
+    if updated_value >= 0:
+        return updated_value
+    else:
+        return 0 * updated_value
+
 
 #: Maps updater names to updater functions
 updater_registry = Registry()
 updater_registry.register('accumulate', update_accumulate)
 updater_registry.register('set', update_set)
 updater_registry.register('merge', update_merge)
+updater_registry.register('nonnegative_accumulate', update_nonnegative_accumulate)
 
 
 ## divider functions
